@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA and W3C, 1996-2005
+ *  (c) COPYRIGHT INRIA and W3C, 1996-2007
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -291,9 +291,8 @@ ThotBool HasNextDoc (Document doc)
   GotoPreviousHTML_callback
   This function is called when the document is loaded
   ----------------------------------------------------------------------*/
-void GotoPreviousHTML_callback (int newdoc, int status, char *urlName,
-                                char *outputfile, AHTHeaders *http_headers,
-                                void * context)
+void GotoPreviousHTML_callback (int newdoc, int status, char *urlName, char *outputfile,
+				char *proxyName, AHTHeaders *http_headers, void * context)
 {
   Document             doc;
   Element	       el;
@@ -474,12 +473,12 @@ void GotoPreviousHTML (Document doc, View view)
   /* is it the current document ? */     
   if (DocumentURLs[doc] && !strcmp (url, DocumentURLs[doc]) && same_form_data)
     /* it's just a move in the same document */
-    GotoPreviousHTML_callback (doc, 0, url, NULL, NULL, (void *) ctx);
+    GotoPreviousHTML_callback (doc, 0, url, NULL, NULL, NULL, (void *) ctx);
   else
     {
       StopTransfer (doc, 1);
       GetAmayaDoc (url, form_data, doc, doc, method, FALSE,
-                   (void (*)(int, int, char*, char*, const AHTHeaders*, void*))
+                   (void (*)(int, int, char*, char*, char*, const AHTHeaders*, void*))
                    GotoPreviousHTML_callback,(void *) ctx);
       /* out of the critic section */
       Back_Forward = FALSE;
@@ -490,9 +489,8 @@ void GotoPreviousHTML (Document doc, View view)
   GotoNextHTML_callback
   This function is called when the document is loaded
   ----------------------------------------------------------------------*/
-void GotoNextHTML_callback (int newdoc, int status, char *urlName,
-                            char *outputfile, AHTHeaders *http_headers,
-                            void * context)
+void GotoNextHTML_callback (int newdoc, int status, char *urlName, char *outputfile,
+			    char *proxyName, AHTHeaders *http_headers, void * context)
 {
   Element	       el;
   Document             doc;
@@ -641,12 +639,12 @@ void GotoNextHTML (Document doc, View view)
   /* is it the current document ? */
   if (DocumentURLs[doc] && !strcmp (url, DocumentURLs[doc]) && same_form_data)
     /* it's just a move in the same document */
-    GotoNextHTML_callback (doc, 0, url, NULL, NULL, (void *) ctx);
+    GotoNextHTML_callback (doc, 0, url, NULL, NULL, NULL, (void *) ctx);
   else
     {
       StopTransfer (doc, 1);
       GetAmayaDoc (url, form_data, doc, doc, method, FALSE,
-                   (void (*)(int, int, char*, char*, const AHTHeaders*, void*)) GotoNextHTML_callback, (void *) ctx);
+                   (void (*)(int, int, char*, char*, char*, const AHTHeaders*, void*)) GotoNextHTML_callback, (void *) ctx);
       /* out of the critic section */
       Back_Forward = FALSE;
     }
