@@ -12,7 +12,7 @@
 #define AM_NEW_CSS		9
 #define AM_NEW_TEMPLATE		10
 #define AM_OPEN_DOCUMENT		11
-#define AM_OPEN_IN_NEW_TAB		12
+#define AM_INNEWTAB		12
 #define AM_OPEN_IN_NEW_WINDOW		13
 #define AM_CLEAR		14
 #define AM_CLICK		15
@@ -362,35 +362,51 @@
 #define AM_DIRECTORY		359
 #define AM_FILE		360
 #define AM_REPLACECURRENT		361
-#define AM_INNEWTAB		362
-#define AM_INNEWWINDOW		363
-#define AM_NOALIASING		364
-#define AM_DATE		365
-#define AM_NEWDOCLOC		366
-#define AM_OPENLOC		367
-#define AM_WARNCTAB		368
-#define AM_MAXURLLIST		369
-#define AM_CLEARURLLIST		370
-#define AM_SHOWSHORTCUTS		371
-#define AM_EXPORT_LENGTH		372
-#define AM_TEMPLATE		373
-#define AM_TEMPLATE_INSTANCE		374
-#define AM_BAD_TEMPLATE		375
-#define AM_SHOW_TEMPLATES		376
-#define AM_CLOSE_WHEN_APPLY		377
-#define AM_NOT_ALLOWED		378
-#define AM_READONLY		379
-#define AM_INVALID_INLINE		380
-#define AM_NO_HEADING_FOUND		381
-#define AM_SAVE_ANYWAY		382
-#define AM_NO_HOST		383
-#define AM_DOC_CHANGED		384
-#define AM_CONFLICT		385
-#define AM_INVALID_SELECTION		386
-#define AM_INVALID_ELEMENT		387
-#define AM_CHANGE_NUMBER		388
-#define AM_MISSING_TITLE		389
-#define AM_TEMPLATE_REPOSITORIES		390
-#define AM_TEMPLATES		391
-#define AM_NUMBER_OCCUR		392
-#define AMAYA_MSG_MAX		393
+#define AM_INNEWWINDOW		362
+#define AM_NOALIASING		363
+#define AM_DATE		364
+#define AM_NEWDOCLOC		365
+#define AM_OPENLOC		366
+#define AM_WARNCTAB		367
+#define AM_MAXURLLIST		368
+#define AM_CLEARURLLIST		369
+#define AM_SHOWSHORTCUTS		370
+#define AM_EXPORT_LENGTH		371
+#define AM_TEMPLATE		372
+#define AM_TEMPLATE_INSTANCE		373
+#define AM_BAD_TEMPLATE		374
+#define AM_SHOW_TEMPLATES		375
+#define AM_CLOSE_WHEN_APPLY		376
+#define AM_NOT_ALLOWED		377
+#define AM_READONLY		378
+#define AM_INVALID_INLINE		379
+#define AM_NO_HEADING_FOUND		380
+#define AM_SAVE_ANYWAY		381
+#define AM_NO_HOST		382
+#define AM_DOC_CHANGED		383
+#define AM_CONFLICT		384
+#define AM_INVALID_SELECTION		385
+#define AM_INVALID_ELEMENT		386
+#define AM_CHANGE_NUMBER		387
+#define AM_MISSING_TITLE		388
+#define AM_TEMPLATES		389
+#define AM_NUMBER_OCCUR		390
+#define AM_NUMBER_OCCUR_HAVE_MAX		391
+#define AM_NUMBER_OCCUR_HAVE_MIN		392
+#define AM_WARNIDS		393
+#define AM_MATHPI		394
+#define AM_SELECT_OPERATOR_TITLE		395
+#define AM_SELECT_OPERATOR_LABEL		396
+#define AM_SELECT_INTEGRAL_TITLE		397
+#define AM_SELECT_INTEGRAL_LABEL		398
+#define AM_SELECT_FENCE_TITLE		399
+#define AM_SELECT_FENCE_LABEL		400
+#define AM_NUMBER_OPERATORS		401
+#define AM_NUMBER_COORDONNATES		402
+#define AM_NUMBER_NUPLE		403
+#define AM_NUMBER_ELEMENTS		404
+#define AM_NUMBER_VARIABLES		405
+#define AM_DEGREE		406
+#define AM_DEGREE_VARIABLE		407
+#define AM_COMPOUND_DOCUMENT		408
+#define AMAYA_MSG_MAX		409
