@@ -115,7 +115,8 @@ static void SetComboValue (wxComboBox *combo, char *value)
   while (*ptr2 != EOS && *ptr2 != ';')
     ptr2++;
   c = *ptr2;
-  *ptr2 = EOS;
+  if (c != EOS)
+    *ptr2 = EOS;
   combo->SetStringSelection (TtaConvMessageToWX (ptr1));
 //  combo->SetValue (TtaConvMessageToWX (ptr1));
   // check if the value is already in the combo list
@@ -132,7 +133,8 @@ static void SetComboValue (wxComboBox *combo, char *value)
       combo->SetValue (TtaConvMessageToWX (ptr1));
     }
     TtaFreeMemory (buffer);
-  *ptr2 = c;
+  if (c != EOS)
+    *ptr2 = c;
 }
 
 /*----------------------------------------------------------------------
@@ -151,9 +153,11 @@ static void SetChoiceValue (wxChoice *choice, char *value)
   while (*ptr2 != EOS && *ptr2 != ';')
     ptr2++;
   c = *ptr2;
-  *ptr2 = EOS;
+  if (c != EOS)
+    *ptr2 = EOS;
   choice->SetStringSelection(TtaConvMessageToWX( ptr1 ));
-  *ptr2 = c;
+  if (c != EOS)
+    *ptr2 = c;
 }
 
 /*----------------------------------------------------------------------
@@ -162,7 +166,7 @@ static void SetChoiceValue (wxChoice *choice, char *value)
   ----------------------------------------------------------------------*/
 void StyleDlgWX::SetColorTextChanged (int id)
 {
-  wxString            value;
+  wxString            value, svalue;
   unsigned short      red;
   unsigned short      green;
   unsigned short      blue;
@@ -213,6 +217,13 @@ void StyleDlgWX::SetColorTextChanged (int id)
           TtaGiveRGB (buffer, &red, &green, &blue);
           wxColour col( red, green, blue );
           XRCCTRL(*this, "wxID_BUTTON_T_COLOR", wxBitmapButton)->SetBackgroundColour( col );
+          // initialize other values
+          svalue = XRCCTRL(*this, "wxID_CHOICE_T_STYLE", wxChoice)->GetStringSelection();
+          if (svalue.Len() == 0)
+            XRCCTRL(*this, "wxID_CHOICE_T_STYLE", wxChoice)->SetStringSelection(TtaConvMessageToWX("solid"));
+          value = XRCCTRL(*this, "wxID_COMBO_BTOP", wxComboBox)->GetValue();
+          if (value.Len() == 0)
+            XRCCTRL(*this, "wxID_COMBO_BTOP", wxComboBox)->SetValue(TtaConvMessageToWX( "medium" ));
         }
     }
   else if (id == bcolor_id)
@@ -226,6 +237,13 @@ void StyleDlgWX::SetColorTextChanged (int id)
           TtaGiveRGB (buffer, &red, &green, &blue);
           wxColour col( red, green, blue );
           XRCCTRL(*this, "wxID_BUTTON_B_COLOR", wxBitmapButton)->SetBackgroundColour( col );
+          // initialize other values
+          svalue = XRCCTRL(*this, "wxID_CHOICE_B_STYLE", wxChoice)->GetStringSelection();
+          if (svalue.Len() == 0)
+            XRCCTRL(*this, "wxID_CHOICE_B_STYLE", wxChoice)->SetStringSelection(TtaConvMessageToWX("solid"));
+          value = XRCCTRL(*this, "wxID_COMBO_BBOTTOM", wxComboBox)->GetValue();
+          if (value.Len() == 0)
+            XRCCTRL(*this, "wxID_COMBO_BBOTTOM", wxComboBox)->SetValue(TtaConvMessageToWX( "medium" ));
         }
     }
   else if (id == lcolor_id)
@@ -239,6 +257,13 @@ void StyleDlgWX::SetColorTextChanged (int id)
           TtaGiveRGB (buffer, &red, &green, &blue);
           wxColour col( red, green, blue );
           XRCCTRL(*this, "wxID_BUTTON_L_COLOR", wxBitmapButton)->SetBackgroundColour( col );
+          // initialize other values
+          svalue = XRCCTRL(*this, "wxID_CHOICE_L_STYLE", wxChoice)->GetStringSelection();
+          if (svalue.Len() == 0)
+            XRCCTRL(*this, "wxID_CHOICE_L_STYLE", wxChoice)->SetStringSelection(TtaConvMessageToWX("solid"));
+          value = XRCCTRL(*this, "wxID_COMBO_BLEFT", wxComboBox)->GetValue();
+          if (value.Len() == 0)
+            XRCCTRL(*this, "wxID_COMBO_BLEFT", wxComboBox)->SetValue(TtaConvMessageToWX( "medium" ));
         }
     }
   else if (id == rcolor_id)
@@ -252,6 +277,13 @@ void StyleDlgWX::SetColorTextChanged (int id)
           TtaGiveRGB (buffer, &red, &green, &blue);
           wxColour col( red, green, blue );
           XRCCTRL(*this, "wxID_BUTTON_R_COLOR", wxBitmapButton)->SetBackgroundColour( col );
+          // initialize other values
+          svalue = XRCCTRL(*this, "wxID_CHOICE_R_STYLE", wxChoice)->GetStringSelection();
+          if (svalue.Len() == 0)
+            XRCCTRL(*this, "wxID_CHOICE_R_STYLE", wxChoice)->SetStringSelection(TtaConvMessageToWX("solid"));
+          value = XRCCTRL(*this, "wxID_COMBO_BRIGHT", wxComboBox)->GetValue();
+          if (value.Len() == 0)
+            XRCCTRL(*this, "wxID_COMBO_BRIGHT", wxComboBox)->SetValue(TtaConvMessageToWX( "medium" ));
         }
     }
   else if (id == borderc_id)
@@ -265,6 +297,13 @@ void StyleDlgWX::SetColorTextChanged (int id)
           TtaGiveRGB (buffer, &red, &green, &blue);
           wxColour col( red, green, blue );
           XRCCTRL(*this, "wxID_BUTTON_BORDER_COLOR", wxBitmapButton)->SetBackgroundColour( col );
+          // initialize other values
+          svalue = XRCCTRL(*this, "wxID_CHOICE_BORDER_STYLE", wxChoice)->GetStringSelection();
+          if (svalue.Len() == 0)
+            XRCCTRL(*this, "wxID_CHOICE_BORDER_STYLE", wxChoice)->SetStringSelection(TtaConvMessageToWX("solid"));
+          value = XRCCTRL(*this, "wxID_COMBO_B", wxComboBox)->GetValue();
+          if (value.Len() == 0)
+            XRCCTRL(*this, "wxID_COMBO_B", wxComboBox)->SetValue(TtaConvMessageToWX( "medium" ));
         }
     }
 }
@@ -918,6 +957,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_SIZE", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_SIZE", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -932,6 +972,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_LINE", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_LINE", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -946,6 +987,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_INDENT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_INDENT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -960,6 +1002,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_VALIGN", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_VALIGN", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -974,6 +1017,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_WORD", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_WORD", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -988,6 +1032,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_LETTER", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_LETTER", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1002,6 +1047,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BGHPOS", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BGHPOS", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1016,6 +1062,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BGVPOS", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BGVPOS", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1030,6 +1077,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BTOP", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BTOP", wxComboBox)->SetInsertionPoint (1);
               // initialize other values
               svalue = XRCCTRL(*this, "wxID_CHOICE_T_STYLE", wxChoice)->GetStringSelection();
               if (svalue.Len() == 0)
@@ -1054,6 +1102,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BBOTTOM", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BBOTTOM", wxComboBox)->SetInsertionPoint (1);
               svalue = XRCCTRL(*this, "wxID_CHOICE_B_STYLE", wxChoice)->GetStringSelection();
               if (svalue.Len() == 0)
                 XRCCTRL(*this, "wxID_CHOICE_B_STYLE", wxChoice)->SetStringSelection(TtaConvMessageToWX( "solid" ));
@@ -1076,6 +1125,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BLEFT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BLEFT", wxComboBox)->SetInsertionPoint (1);
               // initialize other values
               svalue = XRCCTRL(*this, "wxID_CHOICE_L_STYLE", wxChoice)->GetStringSelection();
               if (svalue.Len() == 0)
@@ -1099,6 +1149,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BRIGHT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BRIGHT", wxComboBox)->SetInsertionPoint (1);
               // initialize other values
               svalue = XRCCTRL(*this, "wxID_CHOICE_R_STYLE", wxChoice)->GetStringSelection();
               if (svalue.Len() == 0)
@@ -1122,6 +1173,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_B", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_B", wxComboBox)->SetInsertionPoint (1);
               // initialize other values
               svalue = XRCCTRL(*this, "wxID_CHOICE_BORDER_STYLE", wxChoice)->GetStringSelection();
               if (svalue.Len() == 0)
@@ -1145,6 +1197,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_MTOP", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_MTOP", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1159,6 +1212,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_PTOP", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_PTOP", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1173,6 +1227,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_MBOTTOM", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_MBOTTOM", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1187,6 +1242,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_PBOTTOM", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_PBOTTOM", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1201,6 +1257,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_MLEFT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_MLEFT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1215,6 +1272,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_PLEFT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_PLEFT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1229,6 +1287,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_MRIGHT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_MRIGHT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1243,6 +1302,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_PRIGHT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_PRIGHT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1257,6 +1317,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_MARGIN", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_MARGIN", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1271,6 +1332,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_PADDING", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_PADDING", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1285,6 +1347,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_WIDTH", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_WIDTH", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1299,6 +1362,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_HEIGHT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_HEIGHT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1313,6 +1377,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_TOP", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_TOP", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1327,6 +1392,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_BOTTOM", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_BOTTOM", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1341,6 +1407,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_LEFT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_LEFT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
@@ -1355,6 +1422,7 @@ void StyleDlgWX::OnValueChanged( wxCommandEvent& event )
             {
               value = TtaConvMessageToWX(buffer);
               XRCCTRL(*this, "wxID_COMBO_RIGHT", wxComboBox)->SetValue(value);
+              XRCCTRL(*this, "wxID_COMBO_RIGHT", wxComboBox)->SetInsertionPoint (1);
             }
         }
     }
