@@ -153,6 +153,16 @@ bool AmayaWindow::ClosePage( int position )
   return false;
 }
 
+/*----------------------------------------------------------------------
+ *       Class:  AmayaWindow
+ *      Method:  CloseAllButPage
+ * Description:  ferme toutes les pages sauf une
+  -----------------------------------------------------------------------*/
+bool AmayaWindow::CloseAllButPage( int position )
+{
+  return false;
+}
+
 /*----------------------------------------------------------------------
  *       Class:  AmayaWindow
  *      Method:  GetPage
@@ -495,248 +505,6 @@ void AmayaWindow::OnChar(wxKeyEvent& event)
         event.Skip();
 }
 
-#if 0
-/*----------------------------------------------------------------------
- *       Class:  AmayaWindow
- *      Method:  CheckUnicodeKey
- * Description:  proceed the unicode charactere if it is one
-  -----------------------------------------------------------------------*/
-bool AmayaWindow::CheckUnicodeKey( wxKeyEvent& event )
-{
-  if ((event.GetUnicodeKey()!=0) && !IsSpecialKey(event.GetKeyCode()) && !event.ControlDown() && !event.AltDown())
-    {
-      wxWindow *   p_win_focus         = wxWindow::FindFocus();
-      wxTextCtrl * p_text_ctrl         = wxDynamicCast(p_win_focus, wxTextCtrl);
-      wxComboBox * p_combo_box         = wxDynamicCast(p_win_focus, wxComboBox);
-      wxSpinCtrl * p_spinctrl          = wxDynamicCast(p_win_focus, wxSpinCtrl);
-      // do not proceed any characteres if the focused widget is a textctrl or a combobox or a spinctrl
-      if (!p_text_ctrl && !p_combo_box && !p_spinctrl)
-        {
-          wxButton *       p_button            = wxDynamicCast(p_win_focus, wxButton);
-          wxCheckListBox * p_check_listbox     = wxDynamicCast(p_win_focus, wxCheckListBox);
-          // do not proceed "space" key if the focused widget is a button or a wxCheckListBox
-          if ( !(event.GetKeyCode() == WXK_SPACE && (p_button || p_check_listbox)) )
-            {
-              int thot_keysym = event.GetUnicodeKey();  
-              int thotMask = 0;
-              if (event.ControlDown())
-                thotMask |= THOT_MOD_CTRL;
-              if (event.AltDown())
-                thotMask |= THOT_MOD_ALT;
-              if (event.ShiftDown())
-                thotMask |= THOT_MOD_SHIFT; 
-              ThotInput (GetActiveFrame()->GetFrameId(), thot_keysym, 0, thotMask, thot_keysym);
-              return true;
-            }
-          else
-            event.Skip();	  
-        }
-      else
-        event.Skip();
-    }
-  return false;
-}
-
-/*----------------------------------------------------------------------
- *       Class:  AmayaWindow
- *      Method:  CheckSpecialKey
- * Description:  proceed the special charactere ( F2, TAB ...) if it is one
-  -----------------------------------------------------------------------*/
-bool AmayaWindow::CheckSpecialKey( wxKeyEvent& event )
-{
-  if ( !event.ControlDown() && !event.AltDown() && IsSpecialKey(event.GetKeyCode()))
-    {
-      int thot_keysym = event.GetKeyCode();  
-
-      bool proceed_key = (
-                          thot_keysym == WXK_F2       ||
-                          thot_keysym == WXK_INSERT   ||
-                          thot_keysym == WXK_DELETE   ||
-                          thot_keysym == WXK_HOME     ||
-                          thot_keysym == WXK_PRIOR    ||
-                          thot_keysym == WXK_NEXT     ||
-#ifdef _MACOS
-                          thot_keysym == WXK_PAGEUP   ||
-                          thot_keysym == WXK_PAGEDOWN ||
-#endif /* _MACOS */
-                          thot_keysym == WXK_END      ||
-                          thot_keysym == WXK_LEFT     ||
-                          thot_keysym == WXK_RIGHT    ||
-                          thot_keysym == WXK_UP       ||
-                          thot_keysym == WXK_DOWN     ||
-                          thot_keysym == WXK_ESCAPE   ||
-                          thot_keysym == WXK_BACK     ||
-                          thot_keysym == WXK_RETURN   ||
-                          thot_keysym == WXK_TAB );
-
-#ifdef _MACOS
-      if (proceed_key && thot_keysym == WXK_PAGEUP)
-	    thot_keysym = WXK_PRIOR;
-      if (proceed_key && thot_keysym == WXK_PAGEDOWN)
-	    thot_keysym = WXK_NEXT;
-#endif /* _MACOS */
- 
-      wxWindow *       p_win_focus         = wxWindow::FindFocus();
-      wxPanel *        p_panel             = wxDynamicCast(p_win_focus, wxPanel);
-      wxGLCanvas *     p_gl_canvas         = wxDynamicCast(p_win_focus, wxGLCanvas);
-      wxTextCtrl *     p_text_ctrl         = wxDynamicCast(p_win_focus, wxTextCtrl);
-      wxComboBox *     p_combo_box         = wxDynamicCast(p_win_focus, wxComboBox);
-      wxSpinCtrl *     p_spinctrl          = wxDynamicCast(p_win_focus, wxSpinCtrl);
-
-#if 0
-      /* allow other widgets to handel special keys only when the key is not F2 */
-      if ((p_combo_box || p_text_ctrl || p_spinctrl) && proceed_key && thot_keysym != WXK_F2)
-        {
-          event.Skip();
-          return true;
-        }
-#endif /* 0 */
-
-      /* only allow the F2 special key outside canvas */
-      if (!p_gl_canvas && proceed_key && thot_keysym != WXK_F2)
-        {
-          event.Skip();
-          return true;      
-        }
-
-#ifdef _WINDOWS
-      /* on windows, when the notebook is focused, the RIGHT and LEFT key are forwarded to wxWidgets,
-         we must ignore it */
-      wxNotebook *     p_notebook          = wxDynamicCast(p_win_focus, wxNotebook);
-      if ( p_notebook && proceed_key )
-        {
-          event.Skip();
-          return true;
-        }
-#endif /* _WINDOWS */
-
-      if ( proceed_key )
-        {
-          int thotMask = 0;
-          if (event.ControlDown())
-            thotMask |= THOT_MOD_CTRL;
-          if (event.AltDown())
-            thotMask |= THOT_MOD_ALT;
-          if (event.ShiftDown())
-            thotMask |= THOT_MOD_SHIFT;
-          TTALOGDEBUG_1( TTA_LOG_KEYINPUT, _T("AmayaWindow::SpecialKey thot_keysym=%x"), thot_keysym );
-          ThotInput (GetActiveFrame()->GetFrameId(), thot_keysym, 0, thotMask, thot_keysym);
-          return true;
-        }
-      else
-        return false;
-    }
-  else
-    return false;
-}
-
-/*----------------------------------------------------------------------
- *       Class:  AmayaWindow
- *      Method:  CheckShortcutKey
- * Description:  proceed shortkey combinaisons if it is one
-  -----------------------------------------------------------------------*/
-bool AmayaWindow::CheckShortcutKey( wxKeyEvent& event )
-{
-  wxChar thot_keysym = event.GetKeyCode();  
-
-  int thotMask = 0;
-  if (event.ControlDown())
-    thotMask |= THOT_MOD_CTRL;
-  if (event.AltDown())
-    thotMask |= THOT_MOD_ALT;
-  if (event.ShiftDown())
-    thotMask |= THOT_MOD_SHIFT;
-
-#ifdef _WINDOWS
-  /* on windows, +/= key generate '+' key code, but is should generates '=' value */
-  if (thot_keysym == '+' && !event.ShiftDown())
-    thot_keysym = '=';
-#endif /* _WINDOWS */
-
-  // on windows, CTRL+ALT is equivalent to ALTGR key
-  if ( ((event.ControlDown() && !event.AltDown()) || (event.AltDown() && !event.ControlDown()))
-       && !IsSpecialKey(thot_keysym)
-       // this is for the Windows menu shortcuts, 
-       // ALT+F => should open File menu
-       && !(thot_keysym >= 'A' && thot_keysym <= 'Z' && event.AltDown() && !event.ControlDown()) 
-		                                               
-       )
-    {
-      // le code suivant permet de convertire les majuscules
-      // en minuscules pour les racourcis clavier specifiques a amaya.
-      // OnKeyDown recoit tout le temps des majuscule que Shift soit enfonce ou pas.
-      if (!event.ShiftDown())
-        {
-          // shift key was not pressed
-          // force the lowercase
-          wxString s(thot_keysym);
-          if (s.IsAscii())
-            {
-              TTALOGDEBUG_1( TTA_LOG_KEYINPUT, _T("AmayaWindow::CheckShortcutKey : thot_keysym=%x s=")+s, thot_keysym );
-              s.MakeLower();
-              thot_keysym = s.GetChar(0);
-            }
-        }
-      // Call the generic function for key events management
-      ThotInput (GetActiveFrame()->GetFrameId(), (int)thot_keysym, 0, thotMask, (int)thot_keysym);
-      return true;
-    }
-  /* it is now the turn of special key shortcuts : CTRL+RIGHT, CTRL+ENTER ...*/
-  else if ((event.ControlDown() || event.AltDown()) &&
-           (thot_keysym == WXK_RIGHT ||
-            thot_keysym == WXK_LEFT ||
-            thot_keysym == WXK_RETURN))
-    {
-      TTALOGDEBUG_1( TTA_LOG_KEYINPUT, _T("AmayaWindow::CheckShortcutKey : special shortcut thot_keysym=%x"), thot_keysym );
-      ThotInput (GetActiveFrame()->GetFrameId(), thot_keysym, 0, thotMask, thot_keysym);
-    }
-  else
-    return false;
-}
-
-/*----------------------------------------------------------------------
- *       Class:  AmayaWindow
- *      Method:  IsSpecialKey
- * Description:  proceed the unicode charactere if it is one
-  -----------------------------------------------------------------------*/
-bool AmayaWindow::IsSpecialKey( int wx_keycode )
-{
-  return ( wx_keycode == WXK_BACK ||
-           wx_keycode == WXK_TAB  ||
-           wx_keycode == WXK_RETURN ||
-           wx_keycode == WXK_ESCAPE ||
-           /*wx_keycode == WXK_SPACE  ||*/
-           wx_keycode == WXK_DELETE ||
-           (wx_keycode >= WXK_START && wx_keycode <= WXK_COMMAND)
-           );
-}
-#endif /* 0 */
-
-#if 0
-/*----------------------------------------------------------------------
- *       Class:  AmayaWindow
- *      Method:  SetWindowEnableToolBarButtons
- * Description:  setup the enable/disable state of the toolbar buttons
-  -----------------------------------------------------------------------*/
-void AmayaWindow::SetWindowEnableToolBarButtons( int frame_id )
-{
-  int button_id    = 1;
-  int window_id    = GetWindowId();
-  int doc_id       = TtaGetFrameDocumentId(frame_id);
-  PtrDocument pDoc = LoadedDocument[doc_id-1];
-
-  wxASSERT( window_id > 0 );
-  wxASSERT( frame_id > 0 );
-  wxASSERT( pDoc != NULL );
-     
-  while (button_id < MAX_BUTTON)
-    {
-      if ( WindowTable[window_id].Button[button_id] )
-        WindowTable[window_id].Button[button_id]->Enable( pDoc->EnabledButton[button_id] );
-      button_id++;
-    }
-}
-#endif /* 0 */
 
 /*----------------------------------------------------------------------
  *       Class:  AmayaWindow
