@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996-2005
+ *  (c) COPYRIGHT INRIA, 1996-2007
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -65,20 +65,25 @@
 static int Matrix_counter = 0;
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-static void IfPushMatrix (PtrAbstractBox pAb)
+static ThotBool IfPushMatrix (PtrAbstractBox pAb)
 {
-  if (pAb->AbElement->ElSystemOrigin || pAb->AbElement->ElTransform)
+  if (!pAb->AbPresentationBox &&
+      (pAb->AbElement->ElSystemOrigin || pAb->AbElement->ElTransform))
     {
       Matrix_counter++;
       glPushMatrix ();
+      return TRUE;
     }
+  else
+    return FALSE;
 }
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-static void IfPopMatrix (PtrAbstractBox pAb)
+static ThotBool IfPopMatrix (PtrAbstractBox pAb)
 {
-  if (pAb->AbElement->ElSystemOrigin || pAb->AbElement->ElTransform)
+  if (!pAb->AbPresentationBox &&
+      (pAb->AbElement->ElSystemOrigin || pAb->AbElement->ElTransform))
     {
       if (Matrix_counter > 0)
         {
@@ -89,7 +94,10 @@ static void IfPopMatrix (PtrAbstractBox pAb)
       else
         printf ("Error PopMatrix (%d)\n",Matrix_counter);
 #endif /* _GL_DEBUG */
+      return TRUE;
     }
+  else
+    return FALSE;
 }
 #endif /*_GL*/
 
@@ -204,6 +212,7 @@ void DefBoxRegion (int frame, PtrBox pBox, int xstart, int xstop,
   PtrAbstractBox      pAb;
 #ifdef _GL
   PtrAbstractBox      pClipAb;
+  ThotBool            formatted;
 #endif /* _GL */
   PtrElement          pEl = NULL;
   int                 x1, x2, y1, y2, k;
@@ -223,31 +232,28 @@ void DefBoxRegion (int frame, PtrBox pBox, int xstart, int xstop,
             pBox = pAb->AbBox;
         }
 #ifdef _GL
-      if (FrameTable[frame].FrView == 1)
+      formatted = (FrameTable[frame].FrView == 1 && pAb->AbPSchema &&
+                   pAb->AbPSchema->PsStructName &&
+                   strcmp (pAb->AbPSchema->PsStructName, "TextFile"));
+      if (formatted)
         {
           /* clip on the enclosing box that changes the System origin */
-          if (pAb)
-            pEl = pAb->AbElement;
-          if (pAb && pEl && pEl->ElStructSchema &&
-              strcmp (pEl->ElStructSchema->SsName, "TextFile"))
+          pClipAb = pAb;
+          /* the box could be included within a SVG element */
+          while (pAb)
             {
-              pClipAb = pAb;
-              /* the box could be included within a SVG element */
-              while (pAb)
-                {
-                  if (pAb->AbElement &&
-                      pAb->AbBox &&
-                      pAb->AbElement->ElSystemOrigin)
-                    pClipAb = pAb;
-                  pAb = pAb->AbEnclosing;
-                }
-              if (pClipAb != pBox->BxAbstractBox && pClipAb->AbBox)
-                {
-                  /* clip the enclosing limits */
-                  xstart = xstop = ystart = ystop = -1;
-                  pBox = pClipAb->AbBox;
-                  k = EXTRA_GRAPH;
-                }
+              if (pAb->AbElement &&
+                  pAb->AbBox &&
+                  pAb->AbElement->ElSystemOrigin)
+                pClipAb = pAb;
+              pAb = pAb->AbEnclosing;
+            }
+          if (pClipAb != pBox->BxAbstractBox && pClipAb->AbBox)
+            {
+              /* clip the enclosing limits */
+              xstart = xstop = ystart = ystop = -1;
+              pBox = pClipAb->AbBox;
+              k = EXTRA_GRAPH;
             }
         }
 #endif /* _GL */
@@ -292,6 +298,8 @@ void DefBoxRegion (int frame, PtrBox pBox, int xstart, int xstop,
         {
           if (pBox->BxTMargin < 0)
             y1 += pBox->BxTMargin;
+          else
+            y1 -= 1; // due to dashed borders
           y2 += pBox->BxHeight;
         }
       else
@@ -334,6 +342,7 @@ void UpdateBoxRegion (int frame, PtrBox pBox, int dx, int dy, int dw, int dh)
   PtrAbstractBox      pAb;
 #ifdef _GL
   PtrAbstractBox      pClipAb;
+  ThotBool            formatted;
 #endif /* _GL */
   PtrElement          pEl = NULL;
   int                 x1, x2, y1, y2, cpoints, caret;
@@ -343,30 +352,27 @@ void UpdateBoxRegion (int frame, PtrBox pBox, int dx, int dy, int dw, int dh)
     {
       pAb = pBox->BxAbstractBox;
 #ifdef _GL
-      if (FrameTable[frame].FrView == 1)
+      formatted = (FrameTable[frame].FrView == 1 && pAb->AbPSchema &&
+                   pAb->AbPSchema->PsStructName &&
+                   strcmp (pAb->AbPSchema->PsStructName, "TextFile"));
+      if (formatted)
         {
           /* clip on the enclosing box that changes the System origin */
-          if (pAb)
-            pEl = pAb->AbElement;
-          if (pAb && pEl && pEl->ElStructSchema &&
-              strcmp (pEl->ElStructSchema->SsName, "TextFile"))
+          pClipAb = pAb;
+          while (pAb)
             {
-              pClipAb = pAb;
-              while (pAb)
-                {
-                  if (pAb->AbElement &&
-                      pAb->AbBox &&
-                      pAb->AbElement->ElSystemOrigin)
-                    pClipAb = pAb;
-                  pAb = pAb->AbEnclosing;
-                }
-              if (pClipAb != pBox->BxAbstractBox && pClipAb->AbBox)
-                {
-                  /* clip the enclosing limits */
-                  dx = dy = dw = dh = 0;
-                  pBox = pClipAb->AbBox;
-                  cpoints = EXTRA_GRAPH;
-                }
+              if (pAb->AbElement &&
+                  pAb->AbBox &&
+                  pAb->AbElement->ElSystemOrigin)
+                pClipAb = pAb;
+              pAb = pAb->AbEnclosing;
+            }
+          if (pClipAb != pBox->BxAbstractBox && pClipAb->AbBox)
+            {
+              /* clip the enclosing limits */
+              dx = dy = dw = dh = 0;
+              pBox = pClipAb->AbBox;
+              cpoints = EXTRA_GRAPH;
             }
         }
 #endif /* _GL */
@@ -552,7 +558,8 @@ void DrawFilledBox (PtrBox pBox, PtrAbstractBox pFrom, int frame, PtrFlow pFlow,
                  pParent->AbBox->BxType == BoGhost)
             pParent = pParent->AbEnclosing;
           topdown = (pParent && pParent->AbBox &&
-                     pParent->AbBox->BxType == BoFloatBlock);
+                     (pParent->AbBox->BxType == BoFloatBlock ||
+                     pParent->AbBox->BxType == BoCellBlock));
         }
       /* display all children */
       pChild = pAb->AbFirstEnclosed;
@@ -781,7 +788,7 @@ void DrawFilledBox (PtrBox pBox, PtrAbstractBox pFrom, int frame, PtrFlow pFlow,
             // display an IMG as a PICTURE element
             DisplayPointSelection (frame, pBox, 0);
 #ifdef _GL
-          else if (pFrom->AbElement->ElSystemOrigin)
+          else if (FrameTable[frame].FrView == 1 && pFrom->AbElement->ElSystemOrigin)
             DrawRectangle (frame, 0, 0, 0, 0, width, height, 0, BgSelColor, 2);
 #endif /* _GL */  
           else
@@ -859,35 +866,28 @@ static void OpacityAndTransformNext (PtrAbstractBox pAb, int plane, int frame,
                                      ThotBool activate_opacity)
 {
 #ifdef _GL
-  if (pAb->AbElement && 
-      pAb->AbDepth == plane &&
-      pAb->AbBox)
+  if (!pAb->AbPresentationBox && pAb->AbElement &&
+      pAb->AbDepth == plane && pAb->AbBox)
     {
       if (TypeHasException (ExcIsGroup, pAb->AbElement->ElTypeNumber,
                             pAb->AbElement->ElStructSchema) && 
           pAb->AbOpacity != 1000 && pAb->AbOpacity != 0 &&
-          activate_opacity &&
-          ((xmax - xmin) > 0) && 
-          ((ymax - ymin) > 0))
+          activate_opacity && xmax - xmin > 0 && ymax - ymin > 0)
         {
           if (!pAb->AbBox->VisibleModification && 
               pAb->AbBox->Post_computed_Pic)
             /* display the group image has it is */
             DisplayOpaqueGroup (pAb, frame, xmin, xmax, ymin, ymax, FALSE);
-          else
+          else if (pAb->AbBox->Pre_computed_Pic)
             {
-              if (pAb->AbBox->Pre_computed_Pic)
-                {
-                  OpaqueGroupTexturize (pAb, frame, xmin, xmax, ymin, ymax, FALSE);
-                  ClearOpaqueGroup (pAb, frame, xmin, xmax, ymin, ymax);
-                  DisplayOpaqueGroup (pAb, frame, xmin, xmax, ymin, ymax, TRUE);
-                  /* Unless we can know when 
-                     a box gets its picture or 
-                     when changes are efffective */
-                  OpaqueGroupTextureFree (pAb, frame);	
-                }
+              OpaqueGroupTexturize (pAb, frame, xmin, xmax, ymin, ymax, FALSE);
+              ClearOpaqueGroup (pAb, frame, xmin, xmax, ymin, ymax);
+              DisplayOpaqueGroup (pAb, frame, xmin, xmax, ymin, ymax, TRUE);
+              /* Unless we can know when a box gets its picture or 
+                 when changes are efffective */
+              OpaqueGroupTextureFree (pAb, frame);	
             }
-        }     
+        }
     }
 #endif /* _GL */
 }
@@ -903,9 +903,8 @@ static void OriginSystemExit (PtrAbstractBox pAb, ViewFrame  *pFrame,
   PtrBox              pBox;
   
   pBox = pAb->AbBox;
-  if (pAb->AbElement->ElSystemOrigin && 
-      plane == pAb->AbDepth &&
-      pAb->AbBox)
+  if (!pAb->AbPresentationBox && pAb->AbElement->ElSystemOrigin && 
+      plane == pAb->AbDepth && pAb->AbBox)
     {
       if (pBox && 
           (OldXOrg != 0 || OldYOrg != 0) &&
@@ -931,15 +930,14 @@ void GetBoxTransformedCoord (PtrAbstractBox pAbSeeked, int frame,
                              int *lowerx, int *higherx, int *x, int *y)
 {
 #ifdef _GL
-  PtrAbstractBox      pAb;
+  PtrAbstractBox      pAb, root, pNext;
   PtrBox              pBox;
   ViewFrame          *pFrame;
   int                 plane;
   int                 nextplane;
   int                 l, h;
-  int                 OldXOrg, OldYOrg, 
-    ClipXOfFirstCoordSys, ClipYOfFirstCoordSys;
-
+  int                 OldXOrg, OldYOrg;
+  int                 ClipXOfFirstCoordSys, ClipYOfFirstCoordSys;
   double              winx, winy, finalx, finaly, finalz;
   int                 viewport[4];
   double              projection_view[16];
@@ -951,7 +949,9 @@ void GetBoxTransformedCoord (PtrAbstractBox pAbSeeked, int frame,
   updateStatus = FrameUpdating;
   FrameUpdating = TRUE;  
   pFrame = &ViewFrameTable[frame - 1];
+  // @@@@ TODO: check positioned boxes
   pAb = pFrame->FrAbstractBox;
+  root = pAb;
   GetSizesFrame (frame, &l, &h);
   pBox = pAb->AbBox;
   if (pBox == NULL)
@@ -960,14 +960,11 @@ void GetBoxTransformedCoord (PtrAbstractBox pAbSeeked, int frame,
   plane = 65536;
   nextplane = plane - 1;
   pAb = pFrame->FrAbstractBox;
-  if (FrameTable[frame].FrView == 1 &&
-      pAb->AbPSchema &&
-      pAb->AbPSchema->PsStructName &&
-      (strcmp (pAb->AbPSchema->PsStructName, "TextFile") != 0))
-    formatted = TRUE;
-  else
+  formatted = (FrameTable[frame].FrView == 1 && pAb->AbPSchema &&
+               pAb->AbPSchema->PsStructName &&
+               strcmp (pAb->AbPSchema->PsStructName, "TextFile"));
+  if (!formatted)
     {
-      formatted = FALSE;
       *lowerx += pFrame->FrXOrg;
       *higherx += pFrame->FrXOrg;
       *y += pFrame->FrYOrg;
@@ -986,19 +983,17 @@ void GetBoxTransformedCoord (PtrAbstractBox pAbSeeked, int frame,
       pAb = pFrame->FrAbstractBox;
       while (pAb)
         {
-          if (pAb->AbDepth == plane &&
-              pAb != pFrame->FrAbstractBox &&
+          if (pAb->AbDepth == plane && pAb != pFrame->FrAbstractBox &&
               pAb->AbBox)
             {
               /* box in the current plane */
               pBox = pAb->AbBox;
               if (pAb->AbElement && pAb->AbDepth == plane)
                 { 
-                  if (formatted)
+                  if (formatted && IfPushMatrix (pAb))
                     {
                       /* If the coord sys origin is translated, 
                          it must be before any other transfromation*/
-                      IfPushMatrix (pAb);
                       if (pAb->AbElement->ElSystemOrigin)
                         {
                           is_transformed = TRUE;
@@ -1043,52 +1038,43 @@ void GetBoxTransformedCoord (PtrAbstractBox pAbSeeked, int frame,
               else if (pAb->AbDepth > nextplane)
                 nextplane = pAb->AbDepth;
             }
+
           /* get next abstract box */
-          if (pAb->AbLeafType == LtCompound && 
-              pAb->AbFirstEnclosed)
+          if (pAb->AbLeafType == LtCompound &&  pAb->AbFirstEnclosed &&
+              (pAb == root ||!IsFlow (pAb->AbBox, frame)))
             /* get the first child */
             pAb = pAb->AbFirstEnclosed;
           else
             {
-              /* close the current element */
-              if (formatted && pAb->AbDepth == plane)
+              // go next or up
+              pNext = pAb->AbNext;
+// --------------------------------------------------------------
+              do
                 {
-                  OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
-                  IfPopMatrix (pAb);
-                  OriginSystemExit (pAb, pFrame, plane, &OldXOrg, &OldYOrg, 
-                                    ClipXOfFirstCoordSys, ClipYOfFirstCoordSys);
-                }
-              if (pAb->AbNext)	    
-                /* get the next sibling */
-                pAb = pAb->AbNext;
-              else
-                {
-                  /* go up in the tree */
-                  while (pAb->AbEnclosing && 
-                         pAb->AbEnclosing->AbNext == NULL)
+                  if (formatted && pAb->AbDepth == plane)
                     {
+                      OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
+                      if (IfPopMatrix (pAb))
+                        OriginSystemExit (pAb, pFrame, plane,
+                                          &OldXOrg, &OldYOrg, 
+                                        ClipXOfFirstCoordSys,
+                                          ClipYOfFirstCoordSys);
+                    }
+                  if (pAb == root)
+                    /* all boxes are now managed: stop the loop */
+                    pAb = pNext = NULL;
+                  else if (pNext)
+                    break;
+                  else
+                    {
+                      /* go up in the tree */
                       pAb = pAb->AbEnclosing;
-                      if (formatted && pAb->AbDepth == plane)
-                        {
-                          OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
-                          IfPopMatrix (pAb);
-                          OriginSystemExit (pAb, pFrame, plane, &OldXOrg, &OldYOrg, 
-                                            ClipXOfFirstCoordSys, ClipYOfFirstCoordSys);
-                        }
-                    }
-                  pAb = pAb->AbEnclosing;
-                  if (pAb)
-                    {
-                      if (formatted && pAb->AbDepth == plane)
-                        {	
-                          OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
-                          IfPopMatrix (pAb);
-                          OriginSystemExit (pAb, pFrame, plane, &OldXOrg, &OldYOrg, 
-                                            ClipXOfFirstCoordSys, ClipYOfFirstCoordSys);
-                        }
-                      pAb = pAb->AbNext;
+                      pNext = pAb->AbNext;
                     }
                 }
+              while (pAb);
+              pAb = pNext;
+// --------------------------------------------------------------
             }
         }
     } 
@@ -1273,7 +1259,7 @@ static void SyncBoundingboxes (PtrAbstractBox pInitAb,
 static void ComputeBoundingBoxes (int frame, int xmin, int xmax, int ymin, int ymax,
                                   PtrAbstractBox pInitAb, ThotBool show_bgimage)
 {
-  PtrAbstractBox      pAb, specAb;
+  PtrAbstractBox      pAb, specAb, child;
   PtrBox              pBox, box;
   PtrBox              topBox;
   ViewFrame          *pFrame;
@@ -1307,14 +1293,11 @@ static void ComputeBoundingBoxes (int frame, int xmin, int xmax, int ymin, int y
   Clipy = -1; 
   Clipw = 0; 
   Cliph = 0;  
-  if (FrameTable[frame].FrView == 1 &&
-      pInitAb &&
-      pInitAb->AbPSchema &&
-      pInitAb->AbPSchema->PsStructName &&
-      (strcmp (pInitAb->AbPSchema->PsStructName, "TextFile") != 0))
-    formatted = TRUE;
-  else
-    formatted = FALSE;
+  formatted = (FrameTable[frame].FrView == 1 &&
+               pInitAb &&
+               pInitAb->AbPSchema &&
+               pInitAb->AbPSchema->PsStructName &&
+               (strcmp (pInitAb->AbPSchema->PsStructName, "TextFile") != 0));
   while (plane != nextplane && pInitAb->AbFirstEnclosed)
     /* there is a new plane to display */
     {
@@ -1328,9 +1311,8 @@ static void ComputeBoundingBoxes (int frame, int xmin, int xmax, int ymin, int y
             {
               /* box in the current plane */
               pBox = pAb->AbBox;
-              if (pAb->AbElement && formatted)
+              if (pAb->AbElement && formatted && IfPushMatrix (pAb))
                 {
-                  IfPushMatrix (pAb);
                   if (pAb->AbElement->ElSystemOrigin)
                     DisplayBoxTransformation (pAb->AbElement->ElTransform, 
                                               pFrame->FrXOrg, 
@@ -1339,7 +1321,7 @@ static void ComputeBoundingBoxes (int frame, int xmin, int xmax, int ymin, int y
                     DisplayTransformation (frame,
                                            pAb->AbElement->ElTransform, 
                                            pBox->BxWidth, 
-                                           pBox->BxHeight);     
+                                           pBox->BxHeight);
                 }
               if (pAb->AbOpacity != 1000
                   && !TypeHasException (ExcIsGroup, pAb->AbElement->ElTypeNumber,
@@ -1347,15 +1329,19 @@ static void ComputeBoundingBoxes (int frame, int xmin, int xmax, int ymin, int y
                 {
                   if (pAb->AbFirstEnclosed)
                     {
-                      pAb->AbFirstEnclosed->AbFillOpacity = pAb->AbOpacity;      
-                      pAb->AbFirstEnclosed->AbStrokeOpacity = pAb->AbOpacity; 
+                      child = pAb->AbFirstEnclosed;
+                      while (child)
+                        {
+                          child->AbFillOpacity = pAb->AbOpacity;      
+                          child->AbStrokeOpacity = pAb->AbOpacity;
+                          child = child->AbNext;
+                        } 
                     }
-                  else 
+                  else
                     {
                       pAb->AbFillOpacity = pAb->AbOpacity;      
                       pAb->AbStrokeOpacity = pAb->AbOpacity; 
                     }
-		   	      
                 }
               if (pAb->AbLeafType == LtCompound)
                 {
@@ -1457,6 +1443,7 @@ static void ComputeBoundingBoxes (int frame, int xmin, int xmax, int ymin, int y
 
               if (pAb->AbElement && formatted)
                 IfPopMatrix (pAb);
+
               /* X and Y is the smallest of all enclosed boxes*/
               if (pBox->BxBoundinBoxComputed)
                 {
@@ -1660,11 +1647,10 @@ PtrBox DisplayAllBoxes (int frame, PtrFlow pFlow,
 #ifdef _GL
               if (pAb->AbElement && not_g_opacity_displayed)
                 {
-                  if (formatted)
+                  if (formatted && IfPushMatrix (pAb))
                     {
                       /* If the coord sys origin is translated, 
                          it must be before any other transformation */
-                      IfPushMatrix (pAb);
                       if (pAb->AbElement->ElSystemOrigin)
                         DisplayBoxTransformation (pAb->AbElement->ElTransform, 
                                                   pFrame->FrXOrg, pFrame->FrYOrg);
@@ -1692,17 +1678,21 @@ PtrBox DisplayAllBoxes (int frame, PtrFlow pFlow,
                               pFrame->FrXOrg = 0;
                               pFrame->FrYOrg = 0;
                               ComputeBoundingBoxes (frame, x_min, x_max,
-                                                    y_min, y_max, pAb, show_bgimage);
+                                                    y_min, y_max, pAb,
+                                                    show_bgimage);
                               clipXOfFirstCoordSys = pBox->BxClipX;
                               clipYOfFirstCoordSys = pBox->BxClipY;
                             }
                           else
                             ComputeBoundingBoxes (frame, x_min, x_max,
-                                                  y_min, y_max, pAb, show_bgimage);
+                                                  y_min, y_max, pAb,
+                                                  show_bgimage);
                         }
+
                       if (pAb->AbOpacity != 1000 &&  not_in_feedback)
                         {
-                          if (TypeHasException (ExcIsGroup, pAb->AbElement->ElTypeNumber,
+                          if (TypeHasException (ExcIsGroup,
+                                                pAb->AbElement->ElTypeNumber,
                                                 pAb->AbElement->ElStructSchema) )
                             {
                               if (pAb->AbOpacity == 0 ||
@@ -1714,18 +1704,17 @@ PtrBox DisplayAllBoxes (int frame, PtrFlow pFlow,
                                 }
                               else
                                 {
-#ifdef IV
                                   if (pAb->AbBox->Post_computed_Pic)
                                     {
                                       FreeGlTextureNoCache (pAb->AbBox->Post_computed_Pic);
                                       TtaFreeMemory (pAb->AbBox->Post_computed_Pic);
                                       pAb->AbBox->Post_computed_Pic = NULL; 
                                     }
-                                  OpaqueGroupTexturize (pAb, frame, x_min, x_max,
+                                  OpaqueGroupTexturize (pAb, frame,
+                                                        x_min, x_max,
                                                         y_min, y_max, TRUE);
                                   ClearOpaqueGroup (pAb, frame, x_min, x_max,
                                                     y_min, y_max);
-#endif
                                 }
                             }
                           else if (pAb->AbFirstEnclosed)
@@ -1749,7 +1738,8 @@ PtrBox DisplayAllBoxes (int frame, PtrFlow pFlow,
                           (pBox->BxDisplay || pAb->AbSelected))
                         DrawFilledBox (pBox, pAb, frame, pFlow,
                                        xmin, xmax, ymin, ymax,
-                                       selected, TRUE, TRUE, TRUE, show_bgimage);
+                                       selected, TRUE, TRUE, TRUE,
+                                       show_bgimage);
                       if (pBox->BxNew && pAb->AbFirstEnclosed == NULL)
                         {
                           /* this is a new box */
@@ -1914,35 +1904,42 @@ PtrBox DisplayAllBoxes (int frame, PtrFlow pFlow,
           else
             {
               // go next or up
+              pNext = pAb->AbNext;
 // --------------------------------------------------------------
               do
                 {
-                  pNext = pAb->AbNext;
-                  if (pAb->AbSelected)
-                    selected = FALSE;
 #ifdef _GL
                   if (formatted && pAb->AbDepth == plane)
                     {
                       OpacityAndTransformNext (pAb, plane, frame, x_min, x_max,
                                                y_min, y_max, not_in_feedback);
-                      IfPopMatrix (pAb);
-                      OriginSystemExit (pAb, pFrame, plane, &xOrg, &yOrg, 
-                                        clipXOfFirstCoordSys, clipYOfFirstCoordSys);
+                      if (IfPopMatrix (pAb))
+                        {
+                          OriginSystemExit (pAb, pFrame, plane, &xOrg, &yOrg, 
+                                            clipXOfFirstCoordSys, clipYOfFirstCoordSys);
+                        }
                     }
+                  not_g_opacity_displayed = TRUE;
 #else /* _GL */
                   OpacityAndTransformNext (pAb, plane, frame, xmin, xmax, ymin,
                                            ymax, FALSE);
 #endif /* _GL */
+                  if (pAb->AbSelected)
+                    selected = FALSE;
                   if (pAb == root)
                     /* all boxes are now managed: stop the loop */
-                    pAb = NULL;
-                  else if (pNext == NULL)
-                    /* go up in the tree */
-                    pAb = pAb->AbEnclosing;
+                    pAb = pNext = NULL;
+                  else if (pNext)
+                    break;
                   else
-                    pAb = pNext;
+                    {
+                      /* go up in the tree */
+                      pAb = pAb->AbEnclosing;
+                      pNext = pAb->AbNext;
+                    }
                 }
-              while (pAb && pNext == NULL);
+              while (pAb);
+              pAb = pNext;
 // --------------------------------------------------------------
             }
         }
@@ -1977,7 +1974,7 @@ ThotBool NeedToComputeABoundingBox (PtrAbstractBox pAb, int frame)
 void ComputeChangedBoundingBoxes (int frame)
 {
 #ifdef _GL
-  PtrAbstractBox      pAb;
+  PtrAbstractBox      pAb, root, pNext;
   PtrBox              pBox;
   ViewFrame          *pFrame;
   int                 plane;
@@ -1985,18 +1982,22 @@ void ComputeChangedBoundingBoxes (int frame)
   int                 l, h;
   int                 OldXOrg, OldYOrg, ClipXOfFirstCoordSys, ClipYOfFirstCoordSys;
   ThotBool            updateStatus;
-  ThotBool            show_bgimage;
+  ThotBool            show_bgimage, formatted;
    
 
   // Check if background images should be displayed
   TtaGetEnvBoolean ("ENABLE_BG_IMAGES", &show_bgimage);
   /*if (show_bgimage)
     TtaGetEnvBoolean ("LOAD_IMAGES", &show_bgimage);*/
-
   updateStatus = FrameUpdating;
   FrameUpdating = TRUE;  
   pFrame = &ViewFrameTable[frame - 1];
+  // @@@@ TODO: check positioned boxes
   pAb = pFrame->FrAbstractBox;
+  formatted =  (FrameTable[frame].FrView == 1 && pAb->AbPSchema &&
+                pAb->AbPSchema->PsStructName &&
+                strcmp (pAb->AbPSchema->PsStructName, "TextFile"));
+  root = pAb;
   if (pAb == NULL)
     return;
   pBox = pAb->AbBox;
@@ -2021,8 +2022,7 @@ void ComputeChangedBoundingBoxes (int frame)
       pAb = pFrame->FrAbstractBox;
       while (pAb)
         {
-          if (pAb->AbDepth == plane &&
-              pAb != pFrame->FrAbstractBox &&
+          if (pAb->AbDepth == plane && pAb != pFrame->FrAbstractBox &&
               pAb->AbBox)
             {
               /* box in the current plane */
@@ -2031,20 +2031,20 @@ void ComputeChangedBoundingBoxes (int frame)
                 {
                   /* If the coord sys origin is translated, 
                      it must be before any other transformation*/
-                  IfPushMatrix (pAb);
-                  if (pAb->AbElement->ElSystemOrigin)
-                    DisplayBoxTransformation (pAb->AbElement->ElTransform, 
-                                              pFrame->FrXOrg, pFrame->FrYOrg);
-                  /* Normal transformation*/
-                  if (pAb->AbElement->ElTransform)
-                    DisplayTransformation (frame,
-                                           pAb->AbElement->ElTransform, 
-                                           pBox->BxWidth, 
-                                           pBox->BxHeight);
-		  
-                  if (pAb->AbElement->ElSystemOrigin)
+                  if (formatted && IfPushMatrix (pAb))
                     {
-                      if (pFrame->FrXOrg ||pFrame->FrYOrg)
+                      if (pAb->AbElement->ElSystemOrigin)
+                        DisplayBoxTransformation (pAb->AbElement->ElTransform, 
+                                                  pFrame->FrXOrg, pFrame->FrYOrg);
+                      /* Normal transformation*/
+                      if (pAb->AbElement->ElTransform)
+                        DisplayTransformation (frame,
+                                               pAb->AbElement->ElTransform, 
+                                               pBox->BxWidth, 
+                                               pBox->BxHeight);
+		  
+                      if (pAb->AbElement->ElSystemOrigin &&
+                          (pFrame->FrXOrg ||pFrame->FrYOrg))
                         {
                           OldXOrg = pFrame->FrXOrg;
                           OldYOrg = pFrame->FrYOrg;
@@ -2086,52 +2086,42 @@ void ComputeChangedBoundingBoxes (int frame)
               else if (pAb->AbDepth > nextplane)
                 nextplane = pAb->AbDepth;
             }
+
           /* get next abstract box */
-          if (pAb->AbLeafType == LtCompound && 
-              pAb->AbFirstEnclosed)
+          if (pAb->AbLeafType == LtCompound && pAb->AbFirstEnclosed&&
+              (pAb == root ||!IsFlow (pAb->AbBox, frame)))
             /* get the first child */
             pAb = pAb->AbFirstEnclosed;
           else
             {
-              if (pAb->AbDepth == plane)
+              pNext = pAb->AbNext;
+// --------------------------------------------------------------
+              do
                 {
-                  OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
-                  IfPopMatrix (pAb);
-                  OriginSystemExit (pAb, pFrame, plane, &OldXOrg, &OldYOrg, 
-                                    ClipXOfFirstCoordSys, ClipYOfFirstCoordSys);
-                }
-	      
-              /* get the next sibling */
-              if (pAb->AbNext)    
-                pAb = pAb->AbNext;
-              else
-                {
-                  /* go up in the tree */
-                  while (pAb->AbEnclosing && 
-                         pAb->AbEnclosing->AbNext == NULL)
-                    {		     
-                      pAb = pAb->AbEnclosing;
-                      if (pAb->AbDepth == plane)
-                        {
-                          OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
-                          IfPopMatrix (pAb);
-                          OriginSystemExit (pAb, pFrame, plane, &OldXOrg, &OldYOrg, 
-                                            ClipXOfFirstCoordSys, ClipYOfFirstCoordSys);
-                        }
-                    }
-                  pAb = pAb->AbEnclosing;
-                  if (pAb)
+                  if (pAb->AbDepth == plane)
                     {
-                      if (pAb->AbDepth == plane)
-                        {
-                          OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
-                          IfPopMatrix (pAb);
-                          OriginSystemExit (pAb, pFrame, plane, &OldXOrg, &OldYOrg, 
-                                            ClipXOfFirstCoordSys, ClipYOfFirstCoordSys);
-                        }
-                      pAb = pAb->AbNext;
+                      OpacityAndTransformNext (pAb, plane, frame, 0, 0, 0, 0, FALSE);
+                      if (formatted && IfPopMatrix (pAb))
+                        OriginSystemExit (pAb, pFrame, plane,
+                                          &OldXOrg, &OldYOrg, 
+                                        ClipXOfFirstCoordSys,
+                                          ClipYOfFirstCoordSys);
+                    }
+                  if (pAb == root)
+                    /* all boxes are now managed: stop the loop */
+                    pAb = pNext = NULL;
+                  else if (pNext)
+                    break;
+                  else
+                    {
+                      /* go up in the tree */
+                      pAb = pAb->AbEnclosing;
+                      pNext = pAb->AbNext;
                     }
                 }
+              while (pAb);
+              pAb = pNext;
+// --------------------------------------------------------------
             }
         }
     } 
