@@ -330,11 +330,14 @@ void GL_SetForeground (int fg, ThotBool fillstyle)
 {
   unsigned short  red, green, blue;
   GLubyte         us_opac;
+
   if (fillstyle)
     us_opac = FillOpacity;
   else
-    us_opac = StrokeOpacity;
-  TtaGiveThotRGB (fg, &red, &green, &blue);
+    {
+      us_opac = StrokeOpacity;
+    }
+   TtaGiveThotRGB (fg, &red, &green, &blue);
   glColor4ub ((GLubyte) red,  (GLubyte) green, (GLubyte) blue, (GLubyte) us_opac);    
 }
 
@@ -868,35 +871,136 @@ void DisplayBoxTransformation (void *v_trans, int x, int y)
   ----------------------------------------------------------------------*/
 static void DisplayViewBoxTransformation (PtrTransform Trans, int Width, int Height)
 {
-  float x_trans, y_trans;
-  double  w_scale, h_scale; 
-  ThotBool is_translated, is_scaled;
+  float     x_trans, y_trans, s_width, s_height;
+  double    x_scale, y_scale; 
+  ThotBool  is_translated, is_scaled, is_x_clipped, is_y_clipped;
 
-  x_trans = y_trans = w_scale = h_scale = 0;
-  is_translated = is_scaled = FALSE;
+  x_trans = y_trans = 0;
+  x_scale = y_scale = 1;
+  is_translated = is_scaled = is_x_clipped = is_y_clipped = FALSE;
   while (Trans)
     {
-      switch (Trans->TransType)
+      if (Trans->TransType == PtElViewBox)
         {
-        case  PtElviewboxScale:
-          w_scale = (double) (Width / Trans->XScale);  
-          h_scale = (double) (Height / Trans->YScale); 
-          is_scaled = TRUE;
-          break;
-        case PtElviewboxTranslate:
-          x_trans = Trans->XScale;  
-          y_trans = Trans->YScale; 
-          is_translated = TRUE;
-          break;
-        default:
-          break;	  
+          x_scale = (double) (Width / Trans->VbWidth);
+          y_scale = (double) (Height / Trans->VbHeight);
+          if (Trans->VbAspectRatio == ArNone)
+            /* Do not force uniform scaling: the element's bounding box exactly
+               matches the viewport rectangle */
+            {
+              /* done */;
+            }
+          else
+            /* Force uniform scaling (preserve aspect ratio) */
+            {
+              if (Trans->VbMeetOrSlice == MsMeet)
+                if (x_scale > y_scale)
+                  x_scale = y_scale;
+                else
+                  y_scale = x_scale;
+              else if (Trans->VbMeetOrSlice == MsSlice)
+                if (x_scale > y_scale)
+                  {
+                    y_scale = x_scale;
+                    is_y_clipped = TRUE;
+                  }
+                else
+                  {
+                    x_scale = y_scale;
+                    is_x_clipped = TRUE;
+                  }
+
+              if (Trans->VbAspectRatio == ArXMinYMin)
+                {
+                  x_trans = 0;
+                  y_trans = 0;
+                }
+              else if (Trans->VbAspectRatio == ArXMidYMin)
+                {
+                  y_trans = 0;
+                  s_width = Trans->VbWidth * x_scale;
+                  if (Width != s_width)
+                    x_trans = (Width - s_width) / 2;
+                }
+              else if (Trans->VbAspectRatio == ArXMaxYMin)
+                {
+                  y_trans = 0;
+                  s_width = Trans->VbWidth * x_scale;
+                  if (Width != s_width)
+                    x_trans = (Width - s_width);
+                }
+              else if (Trans->VbAspectRatio == ArXMinYMid)
+                {
+                  x_trans = 0;
+                  s_height = Trans->VbHeight * y_scale;
+                  if (Height != s_height)
+                    y_trans = (Height - s_height) / 2;
+                }
+              else if (Trans->VbAspectRatio == ArXMidYMid)
+                /* align the middle of the element's
+                   viewBox with the middle of the viewport */
+                {
+                  s_height = Trans->VbHeight * y_scale;
+                  s_width = Trans->VbWidth * x_scale;
+                  if (Width != s_width)
+                    x_trans = (Width - s_width) / 2;
+                  if (Height != s_height)
+                    y_trans = (Height - s_height) / 2;
+                }
+              else if (Trans->VbAspectRatio == ArXMaxYMid)
+                {
+                  s_height = Trans->VbHeight * y_scale;
+                  s_width = Trans->VbWidth * x_scale;
+                  if (Width != s_width)
+                    x_trans = (Width - s_width);
+                  if (Height != s_height)
+                    y_trans = (Height - s_height) / 2;                  
+                }
+              else if (Trans->VbAspectRatio == ArXMinYMax)
+                {
+                  x_trans = 0;
+                  s_height = Trans->VbHeight * y_scale;
+                  if (Height != s_height)
+                    y_trans = (Height - s_height);                  
+                }
+              else if (Trans->VbAspectRatio == ArXMidYMax)
+                {
+                  s_height = Trans->VbHeight * y_scale;
+                  s_width = Trans->VbWidth * x_scale;
+                  if (Width != s_width)
+                    x_trans = (Width - s_width) / 2;
+                  if (Height != s_height)
+                    y_trans = (Height - s_height);                  
+                }
+              else if (Trans->VbAspectRatio == ArXMaxYMax)
+                {
+                  s_height = Trans->VbHeight * y_scale;
+                  s_width = Trans->VbWidth * x_scale;
+                  if (Width != s_width)
+                    x_trans = (Width - s_width);
+                  if (Height != s_height)
+                    y_trans = (Height - s_height);
+                }
+            }
+
+          if (x_scale != 1 || y_scale != 1)
+            is_scaled = TRUE;
+
+          x_trans += Trans->VbXTranslate;  
+          y_trans += Trans->VbYTranslate;
+          if (x_trans != 0 || y_trans != 0)
+            is_translated = TRUE;
         }
       Trans = Trans->Next;
     }
-  if (is_scaled)
-    glScaled (w_scale, h_scale, (double) 1);
+  /* How to clip ????
+  if (is_x_clipped || is_y_clipped)
+    @@@clip ((int) -x_trans, (int) -y_trans, Width, Height);
+  */
   if (is_translated)
-    glTranslatef (-x_trans, -y_trans, (float) 0);
+    glTranslatef (x_trans, y_trans, (float) 0);
+  if (is_scaled)
+    glScaled (x_scale, y_scale, (double) 1);
 }
 
 /*----------------------------------------------------------------------
@@ -1298,7 +1402,8 @@ AnimTime ComputeThotCurrentTime (int frame)
 }
 
 /* flag used to display only once opengl status (version, renderer ...)*/
-static ThotBool DisplayOpenGLStatus = TRUE;
+static ThotBool DisplayOpenGLStatus = FALSE;
+/* Put back this boolean to TRUE to have the OpenGL Status at launching */
  
 #define GLU_ERROR_MSG "\nSorry, Amaya requires GLU 1.2 or later.\n"
 /*----------------------------------------------------------------------
