@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996-2005
+ *  (c) COPYRIGHT INRIA, 1996-2007
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -1956,24 +1956,56 @@ void DrawEllips (int frame, int thick, int style, int x, int y, int width,
   The parameter fg indicates the drawing color.
   ----------------------------------------------------------------------*/
 void DrawHorizontalLine (int frame, int thick, int style, int x, int y,
-                         int l, int h, int align, int fg)
+                         int l, int h, int align, int fg, PtrBox box)
 {
   int        Y;
 
+  if (thick <= 0 || fg < 0)
+    return;
   y += FrameTable[frame].FrTopMargin;
-  if (align == 1)
-    Y = y + (h - thick) / 2;
-  else if (align == 2)
-    Y = y + h - (thick + 1) / 2;
-  else
-    Y = y + thick / 2;
-  if (thick > 0 && fg >= 0)
+  if (thick > 1 && style > 5)
     {
+      if (align == 1)
+        DrawRectangle (frame, 1, style, x, y + (h - thick) / 2, l, thick, fg, fg, 2);
+      else if (align == 2)
+        DrawRectangle (frame, 1, style, x, y + h - thick, l, thick, fg, fg, 2);
+      else
+        DrawRectangle (frame, 1, style, x, y, l, thick, fg, fg, 2);
+    }
+  else
+    {
+      if (align == 1)
+        Y = y + (h - thick) / 2;
+      else if (align == 2)
+        Y = y + h - (thick + 1) / 2;
+      else
+        Y = y + thick / 2;
       InitDrawing (style, thick, fg);
       DoDrawOneLine (frame, x, Y, x + l, Y);
     }
 }
 
+/*----------------------------------------------------------------------
+  DrawHat draw a hat aligned top
+  The parameter fg indicates the drawing color.
+  ----------------------------------------------------------------------*/
+void DrawHat (int frame, int thick, int style, int x, int y,
+              int l, int h, int align, int fg)
+{
+  int        Y;
+
+  if (thick > 0 && fg >= 0)
+    {
+      y += FrameTable[frame].FrTopMargin;
+      y += (h - thick) / 2;
+      Y = y + (h - thick) / 2;
+      InitDrawing (style, thick, fg);
+      DoDrawOneLine (frame, x, Y, x + (l / 2), y);
+      DoDrawOneLine (frame, x + (l / 2), y, x + l - thick, Y);
+    }
+}
+
+
 /*----------------------------------------------------------------------
   DrawHorizontalBrace draw a horizontal brace aligned top or bottom
   depending on align value.
@@ -2013,48 +2045,32 @@ void DrawHorizontalBrace (int frame, int thick, int style, int x, int y,
   parameter fg indicates the drawing color
   ----------------------------------------------------------------------*/
 void DrawVerticalLine (int frame, int thick, int style, int x, int y,
-                       int l, int h, int align, int fg)
+                       int l, int h, int align, int fg, PtrBox box)
 {
   int        X;
 
-  if (align == 1)
-    X = x + (l - thick) / 2;
-  else if (align == 2)
-    X = x + l - (thick + 1) / 2;
-  else
-    X = x + thick / 2;
-
+  if (thick <= 0 || fg < 0)
+    return;
   y += FrameTable[frame].FrTopMargin;
-  if (thick > 0 && fg >= 0)
+  if (thick > 1 && style > 5)
     {
-      InitDrawing (style, thick, fg);
-      DoDrawOneLine (frame, X, y, X, y + h);
+      if (align == 1)
+        DrawRectangle (frame, 1, style, x + (l - thick) / 2, y, thick, h, fg, fg, 2);
+      else if (align == 2)
+        DrawRectangle (frame, 1, style, x + l - thick, y, thick, h, fg, fg, 2);
+      else
+        DrawRectangle (frame, 1, style, x, y, thick, h, fg, fg, 2);
     }
-}
-
-/*----------------------------------------------------------------------
-  DrawDoubleVerticalLine draw a double vertical line aligned left center
-  or right depending on align value.
-  parameter fg indicates the drawing color
-  ----------------------------------------------------------------------*/
-void DrawDoubleVerticalLine (int frame, int thick, int style, int x, int y,
-                             int l, int h, int align, int fg)
-{
-  int        X;
-
-  if (align == 1)
-    X = x + (l - thick) / 2;
-  else if (align == 2)
-    X = x + l - (thick + 1) / 2;
   else
-    X = x + thick / 2;
-
-  y += FrameTable[frame].FrTopMargin;
-  if (thick > 0 && fg >= 0)
     {
+      if (align == 1)
+        X = x + (l - thick) / 2;
+      else if (align == 2)
+        X = x + l - (thick + 1) / 2;
+      else
+        X = x + thick / 2;
       InitDrawing (style, thick, fg);
       DoDrawOneLine (frame, X, y, X, y + h);
-      DoDrawOneLine (frame, X + (3 * thick), y, X + (3 * thick), y + h);
     }
 }
 
